==> comptechsoft-vue-foundation-1.0.8.tgz: package/src/~compvuetech/Components/Modals/Import/Import.js <==
import Modal from './../Base/Modal'
import Axios from './../../../Classes/Axios/Axios'

class ImportModal extends Modal {

    constructor(name) {
        super(name)

        this.axios = new Axios()

        /**
         * Selected file object
         */
        this.file = null

        /**
         * Restrictions
         */
        this.allowed_extensions = ['xls', 'xlsx']
        this.min_size = null
        this.max_size = null

        /**
         * Validation Errors
         */
        this.errors = []

        /**
         * Sheet-ul care se prelucreaza
         */
        this.current_sheet = null

        this.header_row = null

        this.map_columns = null

        /**
         * Componenta pentru afisarea unui record
         */
        this.component = null

        this.import = {
            endpoint: null,
            processing: false,
            count: 0,
            total: 0,
            records: [],
        }

    }

    SetEndpoint(value) {
        this.axios.SetEndpoint(value)
        return this
    }

    SetRecordEndpoint(value) {
        this.import.endpoint = value
        return this
    }

    SetComponent(value) {
        this.component = value
        return this
    }

    SetHeaderRow(value) {
        this.header_row = value
        return this
    }

    SetMapColumns(value) {
        this.map_columns = value
        return this
    }

    ValidateFile() {

        Vue.set(this, 'errors', [])

        let size = this.file.size
        let parts = this.file.name.split('.')
        let extension = parts[parts.length-1].toLowerCase()

        if(this.min_size || this.max_size)
        {
            if(this.min_size && (size < this.min_size))
            {
                this.errors.push('Mărimea fișierului (' + size + ') este mai mică decât dimensiunea minimă admisă (' + this.min_size + ').')
            }
            else
            {
                if(this.max_size && (size > this.max_size))
                {
                    this.errors.push('Mărimea fișierului (' + size + ') este mai mare decât dimensiunea maximă admisă (' + this.min_size + ').')
                }
            }
        }

        let exists = _.find(this.allowed_extensions, item => item == extension)
        if( ! exists || (exists == undefined))
        {
            this.errors.push('Extensia fișierul (' + extension + ') nu este permisă. Extensiile acceptate sunt: ' + this.allowed_extensions.join(', '))
        }

    }

    get sheetHeader() {
        if( (this.current_sheet == null) || (! this.axios.response) || (this.header_row == null))
        {
            return null
        }
        let sheet = this.axios.response.sheets[this.current_sheet]
        return sheet[this.header_row]
    }

    get importPercent() {
        return ((this.import.total == 0) ? 0 : (this.import.count * 100/this.import.total).toFixed(2))
    }

    MappedRecord(record) {
        let r = {}
        _.forOwn(this.map_columns, (col, field) => {
            r[field] = record[col]
        })
        return r
    }

    Import(i, vue) {
        Vue.set(this.import, 'count', i - (this.header_row == null ? 0 : 1))
        console.log(this.import.count + '/' + this.import.total)
        if(i <= this.axios.response.sheets[this.current_sheet].length - 1)
        {
            setTimeout( () => {
                let record = this.MappedRecord(this.axios.response.sheets[this.current_sheet][i])
                let axios = new comptechsoft_vue_foundation_src_compvuetech_Classes_Axios_Axios__WEBPACK_IMPORTED_MODULE_1__["default"]()
                    .SetEndpoint(this.import.endpoint)
                    .SetData(record)
                    .OnSuccess( () => {
                        console.log(i + '.' + axios.response.message + '. ' + axios.response.action);
                        this.import.records.push(axios.response)
                        if(axios.response.success)
                        {
                            this.Import(i + 1, vue)
                        }
                        
                    })
                axios.Post()
            }, 1)
        }
        else
        {
            Vue.set(this.import, 'processing', false)
        }
    }

    StartImport(vue) {
        let i = this.header_row == null ? 0 : 1
        Vue.set(this.import, 'total', this.axios.response.sheets[this.current_sheet].length - i)
        Vue.set(this.import, 'processing', true)
        Vue.set(this.import, 'records', [])
        this.Import(i, vue)
        
    }

    Post(vue) {
        let self = this
        let data = new FormData();
        data.append('file', this.file)
        
        this.axios.response = null
        this.current_sheet = null
        
        this.axios
            .SetData(data)
            .OnSuccess(() => {
                vue.$emit('success', this.axios.response)
                console.log(this.axios.response)
            })   
            .OnError(() => {
                vue.$emit('error', this.axios.response)
                console.log(this.axios.response)
            })
            .Post()

    }

}

export default ImportModal

==> comptechsoft-vue-foundation-1.0.10.tgz: package/src/~compvuetech/Components/Modals/Import/Import.js <==
import Modal from './../Base/Modal'
import Axios from './../../../Classes/Axios/Axios'

class ImportModal extends Modal {

    constructor(name) {
        super(name)

        this.axios = new Axios()

        /**
         * Selected file object
         */
        this.file = null

        /**
         * Restrictions
         */
        this.allowed_extensions = ['xls', 'xlsx']
        this.min_size = null
        this.max_size = null

        /**
         * Validation Errors
         */
        this.errors = []

        /**
         * Sheet-ul care se prelucreaza
         */
        this.current_sheet = null

        this.header_row = null

        this.map_columns = null

        /**
         * Componenta pentru afisarea unui record
         */
        this.component = null

        this.import = {
            endpoint: null,
            processing: false,
            count: 0,
            total: 0,
            records: [],
        }

    }

    SetEndpoint(value) {
        this.axios.SetEndpoint(value)
        return this
    }

    SetRecordEndpoint(value) {
        this.import.endpoint = value
        return this
    }

    SetComponent(value) {
        this.component = value
        return this
    }

    SetHeaderRow(value) {
        this.header_row = value
        return this
    }

    SetMapColumns(value) {
        this.map_columns = value
        return this
    }

    ValidateFile() {

        Vue.set(this, 'errors', [])

        let size = this.file.size
        let parts = this.file.name.split('.')
        let extension = parts[parts.length-1].toLowerCase()

        if(this.min_size || this.max_size)
        {
            if(this.min_size && (size < this.min_size))
            {
                this.errors.push('Mărimea fișierului (' + size + ') este mai mică decât dimensiunea minimă admisă (' + this.min_size + ').')
            }
            else
            {
                if(this.max_size && (size > this.max_size))
                {
                    this.errors.push('Mărimea fișierului (' + size + ') este mai mare decât dimensiunea maximă admisă (' + this.min_size + ').')
                }
            }
        }

        let exists = _.find(this.allowed_extensions, item => item == extension)
        if( ! exists || (exists == undefined))
        {
            this.errors.push('Extensia fișierul (' + extension + ') nu este permisă. Extensiile acceptate sunt: ' + this.allowed_extensions.join(', '))
        }

    }

    get sheetHeader() {
        if( (this.current_sheet == null) || (! this.axios.response) || (this.header_row == null))
        {
            return null
        }
        let sheet = this.axios.response.sheets[this.current_sheet]
        return sheet[this.header_row]
    }

    get importPercent() {
        return ((this.import.total == 0) ? 0 : (this.import.count * 100/this.import.total).toFixed(2))
    }

    MappedRecord(record) {
        let r = {}
        _.forOwn(this.map_columns, (col, field) => {
            r[field] = record[col]
        })
        return r
    }

    Import(i, vue) {
        Vue.set(this.import, 'count', i - (this.header_row == null ? 0 : 1))
        console.log(this.import.count + '/' + this.import.total)
        if(i <= this.axios.response.sheets[this.current_sheet].length - 1)
        {
            setTimeout( () => {
                let record = this.MappedRecord(this.axios.response.sheets[this.current_sheet][i])
                let axios = new Axios()
                    .SetEndpoint(this.import.endpoint)
                    .SetData(record)
                    .OnSuccess( () => {
                        console.log(i + '.' + axios.response.message + '. ' + axios.response.action);
                        this.import.records.push(axios.response)
                        // if(axios.response.success)
                        // {
                        //     this.Import(i + 1, vue)
                        // }

                        this.Import(i + 1, vue)
                        
                    })
                axios.Post()
            }, 1)
        }
        else
        {
            Vue.set(this.import, 'processing', false)
        }
    }

    StartImport(vue) {
        let i = this.header_row == null ? 0 : 1
        Vue.set(this.import, 'total', this.axios.response.sheets[this.current_sheet].length - i)
        Vue.set(this.import, 'processing', true)
        Vue.set(this.import, 'records', [])
        this.Import(i, vue)
        
    }

    Post(vue) {
        let self = this
        let data = new FormData();
        data.append('file', this.file)
        
        this.axios.response = null
        this.current_sheet = null
        
        this.axios
            .SetData(data)
            .OnSuccess(() => {
                vue.$emit('success', this.axios.response)
                console.log(this.axios.response)
            })   
            .OnError(() => {
                vue.$emit('error', this.axios.response)
                console.log(this.axios.response)
            })
            .Post()

    }

}

export default ImportModal
